@@ -1,6 +1,6 @@
 """This module contains configuration information.
 
-Copyright 2019--2020 Michael Hayes, UCECE
+Copyright 2019--2021 Michael Hayes, UCECE
 
 """
 
@@ -52,6 +52,14 @@ except:
     
 matrix_inverse_fallback_method = 'ADJ'
 
-use_units = False
 
+# Allow 1 + s, etc.
+loose_units = True
+# Print units with expression.
+show_units = False
+# Print units in abbreviataed form.
 abbreviate_units = True
+# Print units in canonical form.
+canonical_units = False
+# This cannot be enabled without loose units (e.g., s + 1, or s * 'R' * 'C' + 1 would fail).
+check_units = True
