@@ -5,15 +5,15 @@ It introduces three special variables:
    k for discrete-frequency sequences
    z for z-transforms.
 
-Copyright 2020 Michael Hayes, UCECE
+Copyright 2020--2021 Michael Hayes, UCECE
 
 """
 
 import sympy as sym
 from .sym import sympify
-from .nexpr import nexpr, nExpr, n
-from .kexpr import kexpr, kExpr, k
-from .zexpr import zexpr, zExpr, z
+from .nexpr import nexpr, n
+from .kexpr import kexpr, k
+from .zexpr import zexpr, z
 from .dsym import nsym, ksym, zsym, dt, df
 
 from .expr import expr as expr1
@@ -26,6 +26,10 @@ from .seq import seq
 
 def expr(arg, **assumptions):
 
+    # Handle container args.
+    if not isinstance(arg, str) and hasattr(arg, '__iter__'):
+        return expr1(arg, **assumptions)
+    
     expr = sympify(arg, **assumptions)
 
     symbols = expr.free_symbols    
