@@ -4,6 +4,8 @@ Copyright 2021 Michael Hayes, UCECE
 
 """
 
+from .units import u as uu
+from sympy import sqrt
 
 class Domain(object):
     is_undefined_domain = False
@@ -28,28 +30,28 @@ class Domain(object):
 class UndefinedDomain(Domain):
     domain = 'undefined'
     domain_label = 'Undefined'
-    domain_units = ''
+    domain_units = 1
     is_undefined_domain = True
 
 
 class ConstantDomain(Domain):    
     domain = 'constant'
     domain_label = 'Constant'    
-    domain_units = ''
+    domain_units = 1
     is_constant_domain = True
     
 
 class TimeDomain(Domain):
     domain = 'time'
     domain_label = 'Time'
-    domain_units = 's'
+    domain_units = uu.s
     is_time_domain = True
 
     
 class LaplaceDomain(Domain):
     domain = 'laplace'        
     domain_label = 'Laplace frequency'
-    domain_units = 'rad/s'
+    domain_units = uu.rad / uu.s
     is_laplace_domain = True
     is_transform_domain = True
 
@@ -57,7 +59,7 @@ class LaplaceDomain(Domain):
 class FourierDomain(Domain):
     domain = 'fourier'    
     domain_label = 'Frequency'
-    domain_units = 'Hz'
+    domain_units = uu.Hz
     is_fourier_domain = True
     is_transform_domain = True    
 
@@ -65,7 +67,7 @@ class FourierDomain(Domain):
 class AngularFourierDomain(Domain):
     domain = 'angular fourier'
     domain_label = 'Angular frequency'
-    domain_units = 'rad/s'
+    domain_units = uu.rad / uu.s
     is_angular_fourier_domain = True
     is_transform_domain = True    
     
@@ -73,7 +75,7 @@ class AngularFourierDomain(Domain):
 class PhasorTimeDomain(Domain):
     domain = 'phasor'
     domain_label = ''
-    domain_units = ''
+    domain_units = 1
     is_phasor_domain = True
     is_transform_domain = True
 
@@ -81,7 +83,7 @@ class PhasorTimeDomain(Domain):
 class PhasorFrequencyDomain(Domain):
     domain = 'phasor'
     domain_label = 'Angular Frequency'
-    domain_units = 'rad/s'
+    domain_units = uu.rad / uu.s
     is_phasor_domain = True
     is_transform_domain = True            
 
@@ -89,7 +91,7 @@ class PhasorFrequencyDomain(Domain):
 class FourierNoiseDomain(Domain):
     domain = 'fourier noise'    
     domain_label = 'Frequency'
-    domain_units = 'sqrt(Hz)'
+    domain_units = sqrt(uu.Hz)
     is_fourier_noise_domain = True
     is_transform_domain = True
     is_one_sided = True
@@ -98,7 +100,7 @@ class FourierNoiseDomain(Domain):
 class AngularFourierNoiseDomain(Domain):
     domain = 'angular fourier noise'    
     domain_label = 'Angular frequency'
-    domain_units = 'sqrt(rad/s)'
+    domain_units = sqrt(uu.rad / uu.s)
     is_angular_fourier_noise_domain = True
     is_transform_domain = True
     is_one_sided = True    
@@ -107,7 +109,7 @@ class AngularFourierNoiseDomain(Domain):
 class DiscreteTimeDomain(Domain):
     domain = 'discrete time'    
     domain_label = 'Discrete time'
-    domain_units = ''
+    domain_units = 1
     is_discrete_time_domain = True
     is_transform_domain = False    
     
@@ -115,7 +117,7 @@ class DiscreteTimeDomain(Domain):
 class DiscreteFourierDomain(Domain):
     domain = 'discrete fourier'
     domain_label = 'Discrete Fourier'    
-    domain_units = ''
+    domain_units = 1
     is_discrete_fourier_domain = True
     is_transform_domain = True    
     
@@ -123,7 +125,7 @@ class DiscreteFourierDomain(Domain):
 class ZDomain(Domain):
     domain = 'Z'
     domain_label = 'Z'    
-    domain_units = ''
+    domain_units = 1
     is_Z_domain = True
     is_transform_domain = True    
 
@@ -131,7 +133,7 @@ class ZDomain(Domain):
 class SuperpositionDomain(Domain):
     domain = 'superposition'
     domain_label = 'Superposition'    
-    domain_units = ''
+    domain_units = 1
     is_superposition_domain = True
     is_transform_domain = True    
     
