@@ -3,7 +3,7 @@
 """This module provides the Expr class.  This attempts to create a
 consistent interface to SymPy's expressions.
 
-Copyright 2014--2020 Michael Hayes, UCECE
+Copyright 2014--2021 Michael Hayes, UCECE
 
 """
 
@@ -18,11 +18,11 @@ from .domains import UndefinedDomain
 from .quantity import UndefinedQuantity
 from .ratfun import Ratfun
 from .sym import sympify, symsimplify, j, omegasym, symdebug, AppliedUndef
-from .sym import capitalize_name, tsym, symsymbol, symbol_map
+from .sym import capitalize_name, tsym, symsymbol, symbol_map, tausym, nusym, oo
 from .state import state
 from .printing import pprint, pretty, print_str, latex
 from .functions import sqrt, log10, atan2, gcd, exp, Function
-from .units import units, u as uu
+from .units import units, u as uu, dB
 from .utils import as_N_D, as_sum
 from .state import state
 import numpy as np
@@ -32,17 +32,24 @@ from .sym import simplify
 from .simplify import simplify_sin_cos
 from collections import OrderedDict
 
-__all__ = ('expr', 'symbol', 'symbols')
+__all__ = ('expr', 'symbol', 'symbols', 'deg', 'rad', 'degrees', 'radians')
 
 class ExprPrint(object):
 
     @property
     def _pexpr(self):
         """Return expression for printing."""
-        
-        if hasattr(self, 'expr'):
-            return self.expr
-        return self
+
+        if not hasattr(self, 'expr'):
+            return self            
+
+        if state.show_units:
+            if state.canonical_units:
+                return self.expr_with_canonical_units
+            else:
+                return self.expr_with_units        
+        else:
+            return self.expr                
     
     def __repr__(self):
         """This is called by repr(expr).  It is used, e.g., when printing
@@ -77,7 +84,7 @@ class ExprPrint(object):
 
     def latex(self, **kwargs):
         """Make latex string."""
-        return latex(self, **kwargs)
+        return latex(self._pexpr, **kwargs)
 
     def latex_math(self, **kwargs):
         """Make latex math-mode string."""
@@ -126,6 +133,16 @@ class ExprDict(ExprPrint, ExprContainer, ExprMisc, OrderedDict):
 
     """Decorator class for dictionary created by sympy."""
 
+    def __getitem__(self, key):
+
+        # This is used for nodalanalysis to store results
+        # indexed by node name.
+        key2 = str(key)
+        try:
+            return super(ExprDict, self).__getitem__(key2)
+        except:
+            return super(ExprDict, self).__getitem__(key)            
+    
     def evaluate(self):
         """Evaluate each element to convert to floating point.
         The keys are also converted if possible to handle
@@ -235,6 +252,7 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
                     ('constant', 'constant'): 'constant',
                     ('voltage', 'voltage'): 'voltagesquared',
                     ('current', 'current'): 'currentsquared',
+                    ('admittance', 'impedance'): 'transfer',                    
                     ('admittance', 'admittance'): 'admittancesquared',
                     ('impedance', 'impedance'): 'impedancesquared',
                     ('voltage', 'current'): 'power',
@@ -306,7 +324,17 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
     @property
     def _pexpr(self):
         """Return expression for printing."""
-        return self.expr
+
+        if not hasattr(self, 'expr'):
+            return self
+        
+        if state.show_units:
+            if state.canonical_units:
+                return self.expr_with_canonical_units
+            else:
+                return self.expr_with_units                    
+        else:
+            return self.expr                
 
     def __init__(self, arg, **assumptions):
         """
@@ -328,6 +356,10 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
             
             self.assumptions = ass.merge(**assumptions)
             self.expr = arg.expr
+            try:
+                self._units = self._default_units
+            except:
+                self._units = sym.S.One
             return
 
         assumptions = Assumptions(assumptions)
@@ -341,12 +373,21 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
         self.assumptions = assumptions
         # Remove Lcapy assumptions from SymPy expr.
         self.expr = sympify(arg, **self.assumptions.sympy_assumptions())
+        try:
+            self._units = self._default_units
+        except:
+            self._units = sym.S.One        
+
 
     def _class_by_quantity(self, quantity, domain=None):
 
         if domain is None:
             domain = self.domain
         return expressionclasses.get_quantity(domain, quantity)
+
+    def _class_by_domain(self, domain):
+
+        return expressionclasses.get_quantity(domain, self.quantity)    
         
     def as_quantity(self, quantity):
 
@@ -363,7 +404,7 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
         elif quantity == 'power':
             return self.as_power()
         elif quantity == 'undefined':
-            return self.as_expr(expr)        
+            return self.as_expr()        
         raise ValueError('Unknown quantity %s for %s' % (quantity, self))
 
     def as_domain(self, domain):
@@ -405,6 +446,16 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
         if not self.is_unchanging:
             raise ValueError('Expression %s is not constant' % self)
         return self._class_by_quantity(self.quantity)(self)(cexpr(self))
+
+    def as_superposition(self):
+        from .superpositionvoltage import SuperpositionVoltage
+        from .superpositioncurrent import SuperpositionCurrent
+        
+        if self.is_voltage:
+            return SuperpositionVoltage(self)
+        elif self.is_current:
+            return SuperpositionCurrent(self)
+        raise ValueError('Can only convert voltage or current to superposition')
     
     def as_time(self):
         return self.time()
@@ -470,6 +521,25 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
 
         return printer._print(expr)
 
+    @property
+    def canonical_units(self):
+        """Return the canonical units of the expression.  This is a simplified form,
+        so volt * ampere becomes watt."""
+
+        return units.simplify_units(self._units)        
+    
+    @property
+    def units(self):
+        """Return the units of the expression."""
+
+        return self._units
+
+    @units.setter
+    def units(self, unit):
+        """Set the units of the expression; these are simplified into canonical form."""        
+
+        self._units = unit
+
     @property
     def is_causal(self):
         """Return True if zero for t < 0."""
@@ -478,13 +548,8 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
             self.assumptions.infer_from_expr(self)        
         return self.assumptions.is_causal
 
-    @property
-    def causal(self):
-        
-        return self.is_causal
-        
-    @causal.setter
-    def causal(self, value):
+    @is_causal.setter
+    def is_causal(self, value):
 
         self.assumptions.set('causal', value)
 
@@ -495,13 +560,8 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
             self.assumptions.infer_from_expr(self)                
         return self.assumptions.is_dc
 
-    @property
-    def dc(self):
-        
-        return self.is_dc
-
-    @dc.setter
-    def dc(self, value):
+    @is_dc.setter
+    def is_dc(self, value):
 
         self.assumptions.set('dc', value)        
 
@@ -512,13 +572,8 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
             self.assumptions.infer_from_expr(self)                
         return self.assumptions.is_ac
 
-    @property
-    def ac(self):
-        
-        return self.is_ac    
-
-    @ac.setter
-    def ac(self, value):
+    @is_ac.setter
+    def is_ac(self, value):
 
         self.assumptions.set('ac', value)
 
@@ -530,13 +585,8 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
             self.assumptions.infer_from_expr(self)                
         return self.assumptions.is_unknown
 
-    @property
-    def unknown(self):
-        
-        return self.is_unknown    
-
-    @unknown.setter
-    def unknown(self, value):
+    @is_unknown.setter
+    def is_unknown(self, value):
 
         self.assumptions.set('unknown', value)        
 
@@ -580,11 +630,11 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
 
     @property
     def is_phase_radians(self):
-        return self.part == 'phase' and self.units == 'rad'
+        return self.part == 'phase' and self.units == uu.rad
 
     @property
     def is_phase_degrees(self):
-        return self.part == 'phase' and self.units == 'degrees'
+        return self.part == 'phase' and self.units == uu.deg
 
     @property
     def is_real_part(self):
@@ -600,7 +650,25 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
 
     @property
     def is_dB(self):
-        return self.part == 'magnitude' and self.units == 'dB'
+        return self.part == 'magnitude' and self.units == dB
+
+    @property
+    def ac(self):
+        """Return the AC components."""
+
+        return self.as_superposition().ac
+
+    @property
+    def dc(self):
+        """Return the DC component."""
+
+        return self.as_superposition().dc        
+
+    @property
+    def transient(self):
+        """Return the transient component."""
+        
+        return self.as_superposition().transient
     
     @property
     def fval(self):
@@ -722,6 +790,22 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
         s = '%s(' % name
         print(symdebug(self.expr, s, len(name) + 1))
 
+    @property
+    def expr_with_units(self):
+        """Return SymPy expression with units."""
+
+        if self.units == 1:
+            return expr
+        
+        # Don't evaluate otherwise 1 A gets printed as A.
+        return sym.Mul(self.expr, self.units, evaluate=False)
+
+    @property
+    def expr_with_canonical_units(self):
+        """Return SymPy expression with canonical units."""
+
+        return self.expr * self.canonical_units    
+        
     @property
     def func(self):
         """Return the top-level function in the Sympy Expression.
@@ -741,27 +825,25 @@ class Expr(UndefinedDomain, UndefinedQuantity, ExprPrint, ExprMisc):
 
         return self.__class__(-self.expr, **self.assumptions)
 
-    def _incompatible(self, x, op):
-                
-        raise ValueError('Cannot combine %s(%s) with %s(%s) for %s' %
-                         (self.__class__.__name__, self,
-                          x.__class__.__name__, x, op))
+    def _incompatible(self, x, op, reason=''):
 
-    def _incompatible_domains(self, x, op):
-                
-        raise ValueError("""
-Cannot determine %s(%s) %s %s(%s) since the domains are incompatible""" %
+        raise ValueError("Cannot determine %s(%s) %s %s(%s)%s" %
                          (self.__class__.__name__, self, op,
-                          x.__class__.__name__, x))
+                          x.__class__.__name__, x, reason))        
+                
+    def _incompatible_domains(self, x, op):
+
+        self._incompatible(x, op, ' since the domains are incompatible')
 
     def _incompatible_quantities(self, x, op):
 
-        raise ValueError("""
-Cannot determine %s(%s) %s %s(%s) since the units of the result are unsupported.
-As a workaround use x.as_expr() %s y.as_expr()""" %
-                         (self.__class__.__name__, self, op,
-                          x.__class__.__name__, x, op))        
+        self._incompatible(x, op, """ since the units of the result are unsupported.
+As a workaround use x.as_expr() %s y.as_expr()""" % op)
 
+    def _dubious_quantities(self, x, op):
+
+        self._incompatible(x, op, '; you probably should be using convolution')        
+        
     def _add_compatible_domains(self, x):
 
         return self.domain == x.domain
@@ -790,14 +872,27 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
 
         assumptions = self.assumptions.copy()
 
+        if not isinstance(x, Expr):
+            x = expr(x)
+
+        if state.check_units:
+            sunits = self.canonical_units
+            xunits = x.canonical_units
+            
+            if (sunits != xunits and self.expr != 0 and x.expr != 0 and not
+                (state.loose_units and x.is_undefined)):
+                self._incompatible(x, op, ' since the units %s are incompatible with %s' % (self.units, x.units))
+
         cls = self.__class__
         xcls = x.__class__
-        
-        if not isinstance(x, Expr):
-            return cls, self, cls(x), assumptions
-
+            
         if x.is_constant_domain and x.quantity == 'undefined':
-            return cls, self, x, assumptions
+            if state.loose_units or x.expr == 0:
+                # Allow voltage(1) + 2 etc.
+                return cls, self, x, assumptions
+            if self.is_transfer:
+                # Allow transfer(1) == 1
+                return cls, self, x, assumptions                
         
         if self.is_constant_domain and self.quantity == 'undefined':
             return xcls, self, x, assumptions            
@@ -825,10 +920,13 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
 
         # expr + voltage
         if self.quantity == 'undefined':
-            return xcls, self, x, assumptions
+            if state.loose_units or x.is_transfer:
+                return xcls, self, x, assumptions
+            
         # voltage + expr
         if x.quantity == 'undefined':
-            return cls, self, x, assumptions        
+            if state.loose_units or self.is_transfer:            
+                return cls, self, x, assumptions        
         
         self._incompatible_quantities(x, op)        
 
@@ -851,13 +949,19 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
             self.__class__ == TimeDomainExpression):
             return TimeDomainExpression(self.expr * x.expr)
 
-        # Try to convert immitance to a constant so that can handle I(t) * Z
-        if x.is_immitance:
+        # Try to convert immittance to a constant so that can handle I(t) * Z
+        if x.is_immittance:
             try:
+                xunits = x.units
                 x = x.as_constant()
+                x.units = xunits
             except:
                 pass
 
+        if x.is_time_domain and self.is_time_domain:
+            if (self.is_signal and x.is_immittance or x.is_signal and self.is_immittance):
+                self._dubious_quantities(x, '/')                            
+
         if not self._mul_compatible_domains(x):
             self._incompatible_domains(x, '*')                    
 
@@ -888,8 +992,11 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
             cls = x._class_by_quantity(quantity)
         else:
             cls = self._class_by_quantity(quantity)
-            
-        return cls(self.expr * x.expr, **assumptions)
+
+        value = self.expr * x.expr
+        result = cls(value, **assumptions)        
+        result.units = self.units * x.units
+        return result
     
     def __rmul__(self, x):
         """Reverse multiply."""
@@ -902,12 +1009,16 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         if not isinstance(x, Expr):
             x = expr(x)
 
-        # Try to convert immitance to a constant so that can handle V(t) / Z
-        if x.is_immitance:
+        # Try to convert immittance to a constant so that can handle V(t) / Z
+        if x.is_immittance:
             try:
                 x = x.as_constant()
             except:
                 pass
+
+        if x.is_time_domain and self.is_time_domain:
+            if (self.is_signal and x.is_immittance or x.is_signal and self.is_immittance):
+                self._dubious_quantities(x, '/')                
             
         if not self._div_compatible_domains(x):
             self._incompatible_domains(x, '/')                        
@@ -934,8 +1045,12 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
             cls = x._class_by_quantity(quantity)
         else:
             cls = self._class_by_quantity(quantity)
-            
-        return cls(self.expr / x.expr, **assumptions)            
+
+        value = self.expr / x.expr
+        result = cls(value, **assumptions)        
+        result.units = self.units / x.units
+
+        return result
             
     def __rtruediv__(self, x):
         """Reverse true divide."""
@@ -957,7 +1072,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
 
         if isinstance(x, Matrix):
             return x + self.expr
-        
+
         cls, self, x, assumptions = self.__compat_add__(x, '+')
         return cls(self.expr + x.expr, **assumptions)
 
@@ -971,6 +1086,11 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
     def __sub__(self, x):
         """Subtract."""
 
+        from .super import Superposition
+
+        if isinstance(x, Superposition):
+            return -x + self
+        
         cls, self, x, assumptions = self.__compat_add__(x, '-')
         return cls(self.expr - x.expr, **assumptions)
 
@@ -1102,6 +1222,28 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
 
         return self.expr <= x.expr
 
+    def convolve(self, x, commutate=False, **assumptions):
+        """Convolve self with x.
+
+        If `commutate` is True, swap order of functions in integral."""
+
+        if self.domain != x.domain:        
+            self._incompatible_domains(x, 'convolve')
+
+        f1 = self.expr
+        f2 = x.expr
+        if commutate:
+            f1, f2 = f2, f1
+
+        dummyvar = tausym if self.is_time_domain else nusym
+            
+        result = sym.Integral(f1.subs(self.var, self.var - dummyvar) *
+                              f2.subs(self.var, dummyvar),
+                              (dummyvar, -oo, oo))
+        ret = self.__class__(result, **assumptions)
+        ret.units = self.units * x.units * self.domain_units
+        return ret
+    
     def parallel(self, x):
         """Parallel combination."""
 
@@ -1269,6 +1411,8 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         Nnew = sqrt((N.real**2 + N.imag**2).simplify())
         dst = Nnew / Dnew
 
+        dst = dst.as_quantity(self.quantity)
+
         dst.part = 'magnitude'
         return dst
 
@@ -1292,7 +1436,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         # Assume reference is 1.
         dst = 20 * log10(self.magnitude)
         dst.part = 'magnitude'
-        dst.units = 'dB'
+        dst.units = dB
         return dst
 
     @property
@@ -1317,7 +1461,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
             dst = atan2(N.imag, N.real)
 
         dst.part = 'phase'
-        dst.units = 'rad'
+        dst.units = uu.rad
         return dst
 
     @property
@@ -1326,7 +1470,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
 
         dst = self.phase * 180.0 / sym.pi
         dst.part = 'phase'
-        dst.units = 'degrees'
+        dst.units = uu.deg
         return dst
 
     @property
@@ -1642,14 +1786,14 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         """Simplify expression."""
 
         ret = symsimplify(self.expr)
-        ret = units.simplify(ret)
         return self.__class__(ret, **self.assumptions)
 
     def simplify_units(self):
-        """Simplify units."""
+        """Simplify units into canonical form."""
 
-        ret = units.simplify(self.expr)
-        return self.__class__(ret, **self.assumptions)    
+        ret = self.__class__(self, **self.assumptions)
+        ret.units = units.simplify_units(self.units)
+        return ret
 
     def simplify_terms(self):
         """Simplify terms in expression individually."""
@@ -1725,7 +1869,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
     def label_with_units(self):
 
         label = self.label
-        if hasattr(self, 'units') and self.units != '':
+        if hasattr(self, 'units') and self.units != '' and self.units != 1:
             label += ' (%s)' % self.units
         return label    
 
@@ -1736,7 +1880,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         if hasattr(self, 'domain_label'):
             label += '%s' % self.domain_label
         if hasattr(self, 'domain_units'):
-            if self.domain_units != '':
+            if self.domain_units != 1:
                 label += ' (%s)' % self.domain_units
         return label
 
@@ -2167,21 +2311,6 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
 
         return self.__class__(expr, **self.assumptions)
 
-    def apply_unit(self, unit):
-        """Apply unit to expression if `state.use_units` True."""
-
-        if not state.use_units:
-            return self
-
-        value, unit1 = units.as_value_unit(self)
-
-        ret = self * unit
-        # TODO: associate units with s, f, etc.  And C, L, R...?
-        if isinstance(value, (LaplaceDomainExpression, FourierDomainExpression,
-                              AngularFourierDomainExpression)):    
-            ret /= uu.hertz        
-        return ret
-    
     def as_value_unit(self):
         """Return tuple of value and unit.  For example,
 
@@ -2192,9 +2321,8 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         
         from .units import units
 
-        return units.as_value_unit(self)
+        return units.as_value_unit(self.expr)
             
-    
     def as_N_D(self, monic_denominator=False):
         """Responses due to a sum of delayed transient responses
         cannot be factored into ZPK form with a constant delay.
@@ -2215,7 +2343,10 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         D =  s⋅(L⋅s + R)"""
 
         N, D = as_N_D(self.expr, self.var, monic_denominator)
-        return self.__class__(N, **self.assumptions), self.__class__(D, **self.assumptions)
+
+        # Strip quantity and assumptions
+        cls = self._class_by_quantity('undefined')
+        return cls(N), cls(D)
 
     def as_sum(self):
         """Responses due to a sum of delayed transient responses
@@ -2357,7 +2488,7 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         result = foo(coeffs)
         return self.__class__(result, **self.assumptions)
 
-    def change(self, expr, domain=None, **assumptions):
+    def change(self, expr, domain=None, units_scale=None, **assumptions):
         """Change expression class."""
 
         if domain is None:
@@ -2366,8 +2497,17 @@ As a workaround use x.as_expr() %s y.as_expr()""" %
         quantity = self.quantity
 
         cls = self._class_by_quantity(quantity, domain)        
-        return cls(expr, **assumptions)
-    
+        ret = cls(expr, **assumptions)
+
+        if units_scale is not None:
+            ret.units = self.units * units_scale
+        return ret
+
+    def force_time(self):
+
+        if state.force_time:
+            return self.time()
+        return self
 
 def exprcontainer(arg, **assumptions):
 
@@ -2452,6 +2592,40 @@ def symbols(names, **assumptions):
     return symbols
 
 
+def radians(arg, **assumptions):
+    """Convert degrees to radians and set units to radians.  See also rad()
+    that sets units as radians."""
+
+    expr1 = expr(arg / 180 * sym.pi, **assumptions)
+    expr1.units = uu.rad
+    return expr1
+
+
+def degrees(arg, **assumptions):
+    """Convert radians to degrees and set units to degrees.  See also deg()
+    that sets units as degrees."""
+
+    expr1 = expr(arg * 180 / sym.pi, **assumptions)
+    expr1.units = uu.deg
+    return expr1
+
+
+def rad(arg, **assumptions):
+    """Set units to radians.  See also radians() that converts degrees to radians."""
+
+    expr1 = expr(arg, **assumptions)
+    expr1.units = uu.rad
+    return expr1
+
+
+def deg(arg, **assumptions):
+    """Set units to degrees.  See also degrees() that converts radians to degrees."""
+
+    expr1 = expr(arg, **assumptions)
+    expr1.units = uu.deg
+    return expr1
+
+
 from .cexpr import cexpr, ConstantDomainExpression
 from .fexpr import f, fexpr, FourierDomainExpression
 from .texpr import t, texpr, TimeDomainExpression
