@@ -16,6 +16,9 @@ from .currentsquaredmixin import CurrentSquaredMixin
 from .admittancesquaredmixin import AdmittanceSquaredMixin
 from .impedancesquaredmixin import ImpedanceSquaredMixin
 from .powermixin import PowerMixin
+from .units import units, u as uu
+from sympy import sqrt
+from sympy import S
 
 
 quantityclasses = {'voltage': VoltageMixin,
@@ -29,6 +32,19 @@ quantityclasses = {'voltage': VoltageMixin,
                    'impedancesquared': ImpedanceSquaredMixin,
                    'power': PowerMixin}
 
+units_mapping = {
+    '': S.One,
+    'V': uu.volt, 'A': uu.ampere, 
+    'V/Hz': uu.volt / uu.Hz, 'A/Hz': uu.ampere / uu.Hz,
+    'V/sqrt(Hz)': uu.volt / sqrt(uu.Hz), 'A/sqrt(Hz)': uu.ampere / sqrt(uu.Hz),
+    'ohm': uu.ohm, 'S': uu.siemens,
+    'ohm/s': uu.ohm / uu.s, 'S/s': uu.siemens / uu.s,
+    'ohm^2/s^2': (uu.ohm / uu.s)**2, 'S^2/s^2': (uu.siemens / uu.s)**2,    
+    'V^2': uu.volt**2, 'A^2': uu.ampere**2, 
+    'V^2/Hz^2': (uu.volt / uu.Hz)**2, 'A^2/Hz^2': (uu.ampere / uu.Hz)**2,
+    'ohm^2': uu.ohm**2, 'S^2': uu.siemens**2,
+    'W': uu.watt}
+
 
 class ExpressionClassBuilder(dict):
 
@@ -46,42 +62,37 @@ class ExpressionClassBuilder(dict):
             return domainclass
 
         quantityclass = quantityclasses[quantity]
-        quantityunits = quantityclass.units
+        quantityunits = quantityclass.quantity_units
             
-        domainunits = domainclass.domain_units
-
-        units = quantityunits            
+        unitsstring = quantityunits            
         if quantity in ('voltage', 'current'):
             if (domainclass.is_laplace_domain or
                 domainclass.is_fourier_domain or
                 domainclass.is_angular_fourier_domain):
-                units = '%s/%s' % (quantityunits, domainunits)
+                unitsstring = '%s/Hz' % quantityunits
         elif quantity in ('voltagesquared', 'currentsquared'):
             if (domainclass.is_laplace_domain or
                 domainclass.is_fourier_domain or
                 domainclass.is_angular_fourier_domain):                
-                units = '%s/%s^2' % (quantityunits, domainunits)
-        elif quantity in ('impedance', 'admittance'):
+                unitsstring = '%s/Hz^2' % quantityunits
+        elif quantity in ('impedance', 'admittance', 'transfer'):
             if domainclass.is_time_domain:
-                units = '%s/%s' % (quantityunits, domainunits)
+                unitsstring = '%s/s' % quantityunits
         elif quantity in ('admittancesquared', 'impedancesquared'):
             if domainclass.is_time_domain:
-                units = '%s/%s^2' % (quantityunits, domainunits)
+                unitsstring = '%s/s^2' % quantityunits
 
-        # FIXME:  The units of squared quantities are incorrect under transformation
-        # to another domain.  For example, v1(t) * v2(t) has units V^2,
-        # V1(f) * V2(f) has units (V/Hz)^2, but (v1(t) * v2(t))(f) has units V^2/Hz,
-        # and (V1(f) * V2(f))(t) has units V^2/Hz.
-                        
+        # TODO: perhaps rename transfer function in time domain to
+        # impulse response?
         docstring = '%s-domain %s (units %s).' % (domainclass.domain_label,
-                                                  quantity, units)
+                                                  quantity, unitsstring)
 
         suffix = 'Expression'
         name = domainclass.__name__.replace(suffix, quantityclass.quantity.capitalize())
             
         newclass = type(name, (quantityclass, domainclass),
                             {'__doc__': docstring,
-                             'units': units})
+                             '_default_units': units_mapping[unitsstring]})
         self[quantity] = newclass
 
         #print('Created %s %s' % (self.domain, quantity))
