@@ -16,6 +16,8 @@ from .sym import capitalize_name, omegasym
 from .grammar import delimiters
 from .immittancemixin import ImmittanceMixin
 from .superpositioncurrent import SuperpositionCurrent
+from .voltage import voltage
+from .current import current
 from .opts import Opts
 import lcapy
 import inspect
@@ -497,13 +499,13 @@ class Cpt(ImmittanceMixin):
     def V0(self):
         """Initial voltage (for capacitors only)."""
 
-        return 0
+        return voltage(0)
 
     @property
     def I0(self):
         """Initial current (for inductors only)."""
 
-        return 0    
+        return current(0)
     
     @property
     def admittance(self):
@@ -799,9 +801,9 @@ class RC(RLC):
         rnet = self._netmake(nodes=(self.relnodes[0], dummy_node),
                              opts=opts)                                  
 
-        # Use k_b for Boltzmann's constant to avoid clash with k symbol
+        # Use k_B for Boltzmann's constant to avoid clash with k symbol
         # for discrete frequency
-        Vn = 'sqrt(4 * k_b * T * %s)' % self.args[0]
+        Vn = 'sqrt(4 * k_B * T * %s)' % self.args[0]
         vnet = self._netmake_variant('Vn', nodes=(dummy_node, self.relnodes[1]),
                                      args=('noise', Vn), opts=opts)
         return rnet + '\n' + vnet
@@ -890,8 +892,8 @@ class C(RC):
         """Initial voltage (for capacitors only)."""
 
         if self.cct.kind == 'ivp' and self.cpt.has_ic:
-            return self.cpt.v0 / s
-        return 0
+            return voltage(self.cpt.v0 / s)
+        return voltage(0)
 
 
 class CPE(RC):
@@ -1175,8 +1177,8 @@ class L(RLC):
         """Initial current (for capacitors only)."""
 
         if self.cct.kind == 'ivp' and self.cpt.has_ic:
-            return self.cpt.i0 / s
-        return 0
+            return current(self.cpt.i0 / s)
+        return current(0)
     
     @property
     def L(self):
