@@ -1,7 +1,7 @@
 """This module provides support for the common aspects of Circuit and
 Network classes.
 
-Copyright 2014--2020 Michael Hayes, UCECE
+Copyright 2014--2021 Michael Hayes, UCECE
 
 """
 
@@ -25,7 +25,6 @@ from .symbols import omega
 from copy import copy
 
 
-
 class Transformdomains(dict):
 
     def __getattr__(self, attr):
@@ -202,13 +201,13 @@ class Netlist(NetlistMixin, NetfileMixin):
         return result    
 
     def get_I(self, name):
-        """Current through component"""
+        """Current through component (time-domain)"""
 
         result = SuperpositionCurrent()
         for sub in self.sub.values():
             I = sub.get_I(name)
             result.add(I)
-        result = result.canonical()            
+        result = result            
         return result
 
     def get_i(self, name):
@@ -227,7 +226,7 @@ class Netlist(NetlistMixin, NetfileMixin):
         return result
 
     def get_Vd(self, Np, Nm=None):
-        """Voltage drop between nodes"""
+        """Voltage drop between nodes (time-domain)"""
 
         Np, Nm = self._check_nodes(Np, Nm)
         return self._get_Vd(Np, Nm)
