@@ -26,6 +26,8 @@ from .network import Network
 from .immittancemixin import ImmittanceMixin
 from .impedance import impedance
 from .admittance import admittance
+from .voltage import voltage
+from .current import current
 from sympy import Derivative, Integral
 
 
@@ -313,7 +315,7 @@ class OnePort(Network, ImmittanceMixin):
         
         R1 = self.R
         if R1 != 0:
-            Vn = Vnoise('sqrt(4 * k_b * T * %s)' % R1(j * omega))
+            Vn = Vnoise('sqrt(4 * k_B * T * %s)' % R1(j * omega))
             return self + Vn
         return self
 
@@ -780,11 +782,11 @@ class R(OnePort):
 
     def i_equation(self, v, kind='t'):
 
-        return SuperpositionCurrent(SuperpositionVoltage(v).select(kind) / self._Z._selectexpr(kind)).select(kind)
+        return SuperpositionCurrent(SuperpositionVoltage(v).select(kind) / self._Z).select(kind)
 
     def v_equation(self, i, kind='t'):
 
-        return SuperpositionVoltage(SuperpositionCurrent(i).select(kind) * self._Z._selectexpr(kind)).select(kind)
+        return SuperpositionVoltage(SuperpositionCurrent(i).select(kind) * self._Z).select(kind)
     
 
 class G(OnePort):
@@ -808,11 +810,11 @@ class G(OnePort):
 
     def i_equation(self, v, kind='t'):
 
-        return SuperpositionCurrent(SuperpositionVoltage(v).select(kind) / self._Z._selectexpr(kind)).select(kind)
+        return SuperpositionCurrent(SuperpositionVoltage(v).select(kind) / self._Z).select(kind)
 
     def v_equation(self, i, kind='t'):
 
-        return SuperpositionVoltage(SuperpositionCurrent(i).select(kind) * self._Z._selectexpr(kind)).select(kind)
+        return SuperpositionVoltage(SuperpositionCurrent(i).select(kind) * self._Z).select(kind)
     
 
 class L(OnePort):
@@ -849,13 +851,13 @@ class L(OnePort):
             u = tausym
             v = expr(v).subs(t, u)
             return SuperpositionCurrent(expr(Integral(v.expr, (u, -oo, tsym))) / self.L).select(kind)
-        return SuperpositionCurrent(SuperpositionVoltage(v).select(kind) / self.Z._selectexpr(kind)).select(kind)
+        return SuperpositionCurrent(SuperpositionVoltage(v).select(kind) / self.Z(kind)).select(kind)
 
     def v_equation(self, i, kind='t'):
 
         if kind in ('t', 'time', 'super'):
             return SuperpositionVoltage(self.L * expr(Derivative(i.expr, t))).select(kind)
-        return SuperpositionVoltage(SuperpositionCurrent(i).select(kind) * self._Z._selectexpr(kind)).select(kind)
+        return SuperpositionVoltage(SuperpositionCurrent(i).select(kind) * self._Z(kind)).select(kind)
 
     
 class C(OnePort):
@@ -888,7 +890,7 @@ class C(OnePort):
         
         if kind in ('t', 'time', 'super'):
             return SuperpositionCurrent(self.C * expr(Derivative(v.expr, t))).select(kind)
-        return SuperpositionCurrent(SuperpositionVoltage(v).select(kind) / self._Z._selectexpr(kind)).select(kind)
+        return SuperpositionCurrent(SuperpositionVoltage(v).select(kind) / self._Z(kind)).select(kind)
 
     def v_equation(self, i, kind='t'):
 
@@ -898,7 +900,7 @@ class C(OnePort):
             u = tausym
             i = expr(i).subs(t, u)
             return SuperpositionVoltage(expr(Integral(i.expr, (u, -oo, tsym))) / self.C).select(kind)
-        return SuperpositionVoltage(SuperpositionCurrent(i).select(kind) * self._Z._selectexpr(kind)).select(kind)
+        return SuperpositionVoltage(SuperpositionCurrent(i).select(kind) * self._Z(kind)).select(kind)
 
 
 class CPE(OnePort):
@@ -1007,7 +1009,7 @@ class Vdc(VoltageSourceBase):
 
     @property
     def voc(self):
-        return self.v0
+        return voltage(self.v0)
 
 
 class Vac(VoltageSourceBase):
@@ -1046,7 +1048,7 @@ class Vac(VoltageSourceBase):
 
     @property
     def voc(self):
-        return self.v0 * cos(self.omega * t + self.phi)
+        return voltage(self.v0 * cos(self.omega * t + self.phi))
 
 
 class Vnoise(VoltageSourceBase):
@@ -1138,7 +1140,7 @@ class Idc(CurrentSourceBase):
 
     @property
     def isc(self):
-        return self.i0
+        return current(self.i0)
 
 
 class Iac(CurrentSourceBase):
@@ -1175,7 +1177,7 @@ class Iac(CurrentSourceBase):
 
     @property
     def isc(self):
-        return self.i0 * cos(self.omega * t + self.phi)
+        return current(self.i0 * cos(self.omega * t + self.phi))
 
 
 class Inoise(CurrentSourceBase):
