@@ -5,6 +5,9 @@ Copyright 2020--2021 Michael Hayes, UCECE
 """
 
 class Quantity(object):
+    """This is the base class for VoltageMixin, etc.  An Lcapy quantity is
+    not a true quantity but a collection of related quantities, for
+    example, voltage (with units V) and voltage spectral density (with units V/Hz)."""
 
     quantity = ''    
     is_power = False
@@ -13,18 +16,19 @@ class Quantity(object):
     is_impedance = False
     is_admittance = False
     is_transfer = False
-    is_immitance = False
+    is_immittance = False
     is_always_causal = False
     is_undefined = False
     is_voltagesquared = False
     is_currentsquared = False
     is_impedancesquared = False
     is_admittancesquared = False
+    is_ratio = False
+    is_signal = False
     part = ''
 
 
 class UndefinedQuantity(Quantity):
 
     quantity = 'undefined'        
-    is_undefined = True    
-
+    is_undefined = True
