@@ -70,13 +70,25 @@ class Gnode(object):
     def __init__(self, name):
 
         self.name = name
-        self.prev = None
-        self.next = None
         self.dist = 0
-        self.pos = None
+        self._pos = None
         self.fedges = []
         self.redges = []
 
+    @property
+    def pos(self):
+        return self._pos
+
+    @pos.setter    
+    def pos(self, value):
+
+        if value is not None and self._pos is not None:
+            raise RuntimeError('Changing node %s pos' % self)
+        if False and value is not None:
+            print('Setting node %s to pos %f' % (self, value))
+            
+        self._pos = value
+
     def add_fedge(self, edge):
 
         for edge1 in self.fedges:
@@ -101,7 +113,7 @@ class Gnode(object):
     def fmt_name(self):
 
         if isinstance(self.name, tuple):
-            return ', '.join(self.name)
+            return '(' + ', '.join(self.name) + ')'
         return self.name
 
     def __repr__(self):
@@ -109,6 +121,82 @@ class Gnode(object):
         return self.fmt_name
 
     
+class GraphPath(list):
+    """This is a list of edges defining a path through a graph."""
+
+    @property
+    def dist(self):
+
+        distance = 0
+        for edge in self:
+            distance += edge.size
+        return distance
+
+    @property
+    def stretches(self):
+
+        stretches = 0
+        for edge in self:
+            if edge.stretch:
+                stretches += 1
+        return stretches
+
+    def on(self, match_node):
+
+        if self == []:
+            return False
+        
+        for edge in self:
+            if edge.from_gnode == match_node:
+                return True
+
+        return edge.to_gnode == match_node
+
+    def to_dist(self, match_node):
+
+        if match_node == self.from_gnode:
+            return 0
+        
+        distance = 0
+        for edge in self:
+            distance += edge.size
+            if edge.to_gnode == match_node:
+                return distance
+        raise ValueError('Node not on path')
+
+    def from_dist(self, match_node):
+
+        if match_node == self.to_gnode:
+            return 0        
+
+        distance = 0
+        for edge in reversed(self):
+            distance += edge.size
+            if edge.from_gnode == match_node:
+                return distance
+        raise ValueError('Node not on path')    
+
+    @property    
+    def gnodes(self):
+        """Return list of nodes along path including end nodes."""
+        
+        nodes = []
+        nodes.append(self.from_gnode)
+        for edge in self:
+            nodes.append(edge.to_gnode)
+        return nodes
+    
+    @property
+    def to_gnode(self):
+
+        return self[-1].to_gnode
+
+    @property
+    def from_gnode(self):
+
+        return self[0].from_gnode
+
+                
 class Graph(dict):
     """Drawing graph"""
 
@@ -186,18 +274,20 @@ class Graph(dict):
         return unique(self.cnodes.values())
 
     def add_start_nodes(self):
+        """Nodes without forward edges are connected to the end node.
+        Nodes without reverse edges are connected to the start node."""
 
         if 'start' in self:
             return
 
-        gnodes = self.values()
         start = self.add_node('start')
         end = self.add_node('end')
 
+        gnodes = self.values()
         for gnode in gnodes:
-            if gnode.redges == []:
+            if gnode.redges == [] and gnode != start:
                 self.add_edges(None, start, gnode, 0, True)
-            if gnode.fedges == []:
+            if gnode.fedges == [] and gnode != end:
                 self.add_edges(None, gnode, end, 0, True)
 
     def assign_fixed1(self, gnode):
@@ -218,7 +308,7 @@ class Graph(dict):
         """ Assign node positions to nodes with fixed edge lengths to
         nodes with known positions.  Iterate until no more changes.
         This stage is not needed but provides a minor optimisation."""
-        
+
         changes = True
         while changes and unknown != []:
             for n in unknown:
@@ -228,7 +318,7 @@ class Graph(dict):
                     unknown.remove(n)
                     break
 
-    def assign_stretch1(self, gnode):
+    def assign_stretchy1(self, gnode, unknown):
 
         # For each node, find the longest path between nodes with
         # known positions.  The path between the nodes with known
@@ -241,120 +331,200 @@ class Graph(dict):
         # the node is dangling and the stretch is zero.
         
         # TODO, check for multiple paths with a conflict, for example,
-        # a stretchy path of a longser distance than a fixed path.
+        # a stretchy path of a longer distance than a fixed path.
+        
+        to_path = self.path_to_closest_known(gnode, forward=True)
+        from_path = self.path_to_closest_known(gnode, forward=False)
 
-        to_stretches = 0
-        to_dist = 0
-        self.longest_path_to_known(gnode)
-        to_gnode = gnode
-        while to_gnode.next is not None:
-            if to_gnode.next.stretch:
-                to_stretches += 1
-            to_dist += to_gnode.next.size
-            to_gnode = to_gnode.next.to_gnode
-
-        from_stretches = 0
-        from_dist = 0
-        self.longest_path_to_known(gnode, False)
-        from_gnode = gnode
-        while from_gnode.next is not None:
-            if from_gnode.next.stretch:
-                from_stretches += 1
-            from_dist += from_gnode.next.size
-            from_gnode = from_gnode.next.to_gnode
+        to_gnode = to_path.to_gnode
+        # Note, from_path is reversed (the edges are backward edges)
+        from_gnode = from_path.to_gnode
 
         if from_gnode.name == 'start' and to_gnode.name == 'end':
             # There is a chance that we have naively picked an
             # unlucky gnode. 
             return False
 
-        if from_gnode.name == 'start':
+        if from_gnode.name == 'start' and len(to_path) == 1:
             # Have dangling node, so no stretch needed.
-            gnode.pos = to_gnode.pos - to_dist
+            gnode.pos = to_gnode.pos - to_path.dist
+            unknown.remove(gnode.name)
             return True
 
-        if to_gnode.name == 'end':
+        if to_gnode.name == 'end' and len(from_path) == 1:
             # Have dangling node, so no stretch needed.
-            gnode.pos = from_gnode.pos + from_dist
+            gnode.pos = from_gnode.pos + from_path.dist
+            unknown.remove(gnode.name)
             return True
 
+        path = self.longest_path(from_gnode, to_gnode)
+
+        if len(path) == 1:
+            return False
+        
+        # The gnode may not be on this path but this does not matter.
+        # It will be processed asain later.
+
+        stretches = path.stretches
         separation = to_gnode.pos - from_gnode.pos
-        extent = to_dist + from_dist
+        extent = path.dist        
+
         if extent - separation > 1e-6:
-            raise ValueError('Inconsistent %s schematic graph, component will not fit:  separation %s between %s and %s, need %s.\n%s' % (self.name, separation, from_gnode, to_gnode, extent, self))
-            
-        if from_stretches == 0:
-            gnode.pos = from_gnode.pos + from_dist
-        elif to_stretches == 0:
-            gnode.pos = to_gnode.pos - to_dist
-        else:
-            stretch = (separation - extent) / (to_stretches + from_stretches)
-            gnode.pos = from_gnode.pos + from_dist + stretch * from_stretches
+            raise ValueError('Inconsistent %s schematic graph, component(s) will not fit:  separation %s between %s and %s, need %s.\n%s' % (self.name, separation, from_gnode, to_gnode, extent, self))
+
+        
+        # This how much each component needs to stretch.
+        stretch = (separation - extent) / stretches
+
+        pos = from_gnode.pos
+        for edge in path:
+            pos += edge.size
+            if edge.stretch:
+                pos += stretch
+
+            if edge != path[-1]:
+                edge.to_gnode.pos = pos
+                unknown.remove(edge.to_gnode.name)
+
         return True
 
-    def assign_stretch(self, unknown):
+    def assign_stretchy(self, unknown):
         """Use a worklist algorithm to assign nodes with unknown positions
-        that are connected via stretchable edges to the known nodes.
-
-        """
+        that are connected via stretchable edges to the known nodes."""
 
         changes = True
         while changes and unknown != []:
             for n in unknown:
                 gnode = self[n]
-                changes = self.assign_stretch1(gnode)
-                if changes:
+                if gnode.pos is not None:
                     unknown.remove(n)
+                    break
+                
+                changes = self.assign_stretchy1(gnode, unknown)
+                if changes:
                     self.assign_fixed(unknown)
                     break
 
-    def analyse(self, stage=None):
+    def assign_longest(self, path, unknown):
 
-        self.add_start_nodes()
+        if path == []:
+            raise RuntimeError('Empty path')
+        
+        pos = 0
+        for edge in path:
+            edge.from_gnode.pos = pos
+            pos += edge.size
+            unknown.remove(edge.from_gnode.name)
+
+        edge = path[-1]
+        edge.to_gnode.pos = pos
+        unknown.remove(edge.to_gnode.name)
+
+    def prune(self):
+        """Remove redundant paths from graph.  If there are two
+        parallel stretchy edges, the longest is chosen."""
 
         for gnode in self.values():
-            gnode.pos = None
 
+            def check(edges, grizzle=False):
+
+                # If don't have multiple edges, cannot have redundancy
+                if len(edges) < 2:
+                    return edges
+                
+                fromto = {}
+                for edge in edges:
+                    key = (edge.from_gnode, edge.to_gnode)
+                    if key not in fromto:
+                        fromto[key] = []
+                    fromto[key].append(edge)
+
+                newedges = []                        
+                for key, edges in fromto.items():
+
+                    best_edge = edges[0]
+                    fixed = False
+                    size = 0
+                    for edge in edges:
+                        if not edge.stretch:
+                            fixed = True
+                            size = edge.size
+                            best_edge = edge
+                            break
+
+                    if fixed and grizzle:
+                        for edge in edges:
+                            if edge.size != size and not edge.stretch:
+                                print('Component fixed size violation for %s, expected %f, got %f' % (edge.cpt, size, edge.size))
+                            elif edge.size > size:                                
+                                print('Component size violation for %s, expected %f or less, got %f' % (edge.cpt, size, edge.size))
+                                
+                    elif not fixed:
+                        # Choose largest component size since all are stretchy
+                        for edge in edges:
+                            if edge.size > size:
+                                size = edge.size
+                                best_edge = edge
+
+                    newedges.append(best_edge)
+
+                return newedges
+                    
+
+            gnode.fedges = check(gnode.fedges, grizzle=True)
+            gnode.redges = check(gnode.redges)            
+
+    def analyse(self, stage=None):
+        """
+        Analyse graph assigning gnode positions.
+
+        stage 0 --- add start/end gnodes
+        stage 1 --- prune redundant edges
+        stage 2 --- assign gnode positions on longest path
+        stage 3 --- assign gnode positions with fixed positions to known gnodes
+        stage 4 --- assign all gnode positions
+        """
+        
         unknown = list(self.keys())
-        unknown.remove('start')
-        unknown.remove('end')
 
         if unknown == []:
+            # If there are no constraints, all the nodes have distance 0.
             pos = {}
             for n, gnode in self.cnodes.items():
                 pos[n] = 0
             return pos, 0
+        
+        self.add_start_nodes()
+        unknown.append('start')
+        unknown.append('end')        
 
-        # Find longest path through the graph.
-        self.longest_path(self['start'])
+        if stage == 0:
+            return
 
-        try:
-            # Nodes on the longest path have known positions.
-            gnode = self['end']
-            while gnode != None and gnode.name != 'start':
-                if gnode.name in unknown:
-                    unknown.remove(gnode.name)
-                gnode.path = True
-                gnode.pos = gnode.dist
-                gnode.fixed = True
-                gnode = gnode.prev.from_gnode
-                self['start'].pos = 0
-        except AttributeError:
-            msg = "The %s schematic graph is dodgy, probably a "
-            "component is attached to the wrong nodes.\n" % self.name
-            if self.debug:
-                msg += str(self)
-            raise AttributeError(msg)
+        # Prune redundant edges from graph.        
+        self.prune()
 
         if stage == 1:
             return
             
-        self.assign_fixed(unknown)
+        # Find longest path through the graph.  This provides the
+        # dimension for the graph.
+        path = self.longest_path(self['start'], self['end'])
 
+        # Assign gnodes on the longest path.        
+        self.assign_longest(path, unknown)
+        
         if stage == 2:
             return
 
-        self.assign_stretch(unknown)
+        # Assign gnodes at a fixed distance from nodes with known positions.
+        self.assign_fixed(unknown)
+
+        if stage == 3:
+            return
+
+        # Assign remaining gnodes.
+        self.assign_stretchy(unknown)
 
         if unknown != []:
             raise ValueError('Cannot assign nodes %s for %s graph.\n%s' %
@@ -378,8 +548,68 @@ class Graph(dict):
 
         return pos, distance_max
 
-    def longest_path_to_known(self, start, forward=True):
-        """Find longest path through DAG to a node with a known dist."""
+    def longest_path(self, from_gnode, to_gnode, forward=True):
+        """Find longest path through DAG from from_gnode to to_gnode
+        or to a gnode with a known position."""
+
+        # gnode.dist specifies the distance to the to_gnode.  It is
+        # None if the distance has yet to be determined and is -1 if
+        # the to_gnode cannot be reached from gnode.
+        for gnode in self.values():
+            gnode.dist = None
+            gnode.next = None            
+
+        def traverse(gnode):
+
+            # If have visited this gnode before then know dist.
+            if gnode.dist is not None:
+                return gnode.dist
+
+            # If have reached goal, return dist of 0.
+            if gnode == to_gnode:
+                gnode.dist = 0                
+                return 0
+
+            # Do not traverse nodes at known positions.
+            if gnode.pos is not None and gnode != from_gnode:
+                return -1
+
+            gnode.dist = -1
+
+            edges = gnode.fedges if forward else gnode.redges
+            for edge in edges:
+                dist = traverse(edge.to_gnode)
+                if dist >= 0 and gnode.dist < dist + edge.size:
+                    gnode.dist = dist + edge.size
+                    # Mark current best edge
+                    gnode.next = edge
+
+            return gnode.dist
+
+        try:
+            traverse(from_gnode)
+        except RuntimeError:
+            msg = "The %s schematic graph is dodgy, probably a component is attached to the wrong nodes.\n" % self.name
+            if self.debug:
+                msg += str(self)
+            
+            raise RuntimeError(msg)
+
+        return self.makepath(from_gnode)
+
+    def makepath(self, from_gnode):
+        
+        # Construct path
+        path = GraphPath()
+        gnode = from_gnode
+        while gnode.next is not None:
+            path.append(gnode.next)
+            gnode = gnode.next.to_gnode
+            
+        return path
+        
+    def path_to_closest_known(self, from_gnode, forward=True):
+        """Find path through DAG to the closest node with a known pos."""
 
         def traverse(gnode):
 
@@ -404,9 +634,9 @@ class Graph(dict):
                     gnode.next = edge
             return min_dist
 
-        start.dist = 0
+        from_gnode.dist = 0
         try:
-            return traverse(start)
+            traverse(from_gnode)
         except RuntimeError:
             # W a b; right
             # W c d; right
@@ -417,42 +647,8 @@ class Graph(dict):
                 msg += str(self)
             raise RuntimeError(msg)
 
-
-    def longest_path(self, start, forward=True):
-        """Find longest path through DAG."""
-
-        for gnode in self.values():
-            gnode.dist = -1
-            gnode.prev = None
-            gnode.next = None
-
-        def traverse(gnode):
-
-            if gnode.pos is not None:
-                return True
-
-            edges = gnode.fedges if forward else gnode.redges
-            for edge in edges:
-                next_gnode = edge.to_gnode
-                dist = gnode.dist + edge.size
-                if dist > next_gnode.dist:
-                    next_gnode.dist = dist
-                    next_gnode.prev = edge
-                    gnode.next = edge
-                    if traverse(next_gnode):
-                        return True
-            return False
-
-        start.dist = 0
-        try:
-            traverse(start)
-        except RuntimeError:
-            msg = "The %s schematic graph is dodgy, probably a component is attached to the wrong nodes.\n" % self.name
-            if self.debug:
-                msg += str(self)
-            
-            raise RuntimeError(msg)
-
+        return self.makepath(from_gnode)
+        
     def check_positions(self):
 
         for gnode in self.values():
@@ -496,11 +692,10 @@ class Graph(dict):
             run_dot(dotfilename, filename)
             return
 
-        if stage != 0:
-            self.analyse(stage=stage)
+        self.analyse(stage=stage)
 
         dotfile = open(filename, 'w')
-        dotfile.write('strict digraph {\n\tgraph [rankdir=LR];\n')
+        dotfile.write('digraph {\n\tgraph [rankdir=LR];\n')
 
         for gnode in self.values():
             if hasattr(gnode, 'fixed'):
