@@ -11,6 +11,7 @@ import sympy as sym
 from .expr import Expr, ExprDict, expr
 from .sym import tsym, omega0sym, symbols_find, is_sympy, symsymbol
 from .acdc import is_ac
+from .state import state
 from .domains import SuperpositionDomain
 from .printing import pprint, pretty, latex
 from .classmap import domain_kind_quantity_to_class, expr_to_domain_kind
@@ -61,6 +62,10 @@ class Superposition(SuperpositionDomain, ExprDict):
         super (Superposition, self).__init__()
 
         for arg in args:
+
+            if not isinstance(arg, (Superposition)):
+                arg = expr(arg).as_quantity(self.quantity)
+            
             self.add(arg)
 
     def _representation(self):
@@ -143,6 +148,15 @@ class Superposition(SuperpositionDomain, ExprDict):
             syms.update(expr1.symbols)
         return syms
 
+    @property
+    def units(self):
+        """Return the units of the expression.  However, since this is a
+        superposition, units are not defined.  Instead, it is
+        necessary to transform to a specific domain.  For example,
+        using `V(s)`."""
+
+        raise AttributeError("""Units are not defined for a superposition; convert to a specific domain, say using `V(t)` or `V(s)`.""")
+    
     def ac_keys(self):
         """Return list of keys for all ac components."""
 
@@ -339,7 +353,7 @@ class Superposition(SuperpositionDomain, ExprDict):
         return self.__add__(x)
 
     def __sub__(self, x):
-        return -x + self
+        return self + (-x)
 
     def __rsub__(self, x):
         return -self + x
@@ -382,37 +396,39 @@ class Superposition(SuperpositionDomain, ExprDict):
                 return True
         return False    
 
-    def _decompose_timedomain_expr(self, expr):
+    def _decompose_timedomain_expr(self, expr1):
         """Decompose a time domain expr into AC, DC, and s-domain
         transient components."""
 
         result = {}
         
         # Extract DC components
-        dc = expr.expr.coeff(tsym, 0)
+        dc = expr1.expr.coeff(tsym, 0)
+        dc = ConstantDomainExpression(dc).as_quantity(self.quantity)
         if dc != 0:
-            result['dc'] = ConstantDomainExpression(dc)
-            expr -= dc
+            result['dc'] = dc
+            expr1 -= dc
 
-        if expr == 0:
+        if expr1 == 0:
             return result
 
         # Extract AC components        
         ac = 0
-        terms = expr.expr.as_ordered_terms()
+        terms = expr1.expr.as_ordered_terms()
         for term in terms:
             if is_ac(term, tsym):
-                 p = TimeDomainExpression(term).phasor()
-                 result[p.omega] = p
-                 ac += term
+                eterm = expr(term).as_quantity(self.quantity)
+                p = eterm.phasor()
+                result[p.omega] = p
+                ac += eterm
 
-        expr -= ac
-        if expr == 0:
+        expr1 -= ac
+        if expr1 == 0:
             return result
 
         # The remaining components are considered transient
         # so convert to Laplace representation.
-        sval = expr.laplace()
+        sval = expr1.laplace()
 
         result['s'] = sval
         return result
@@ -777,6 +793,11 @@ phasor, for example, using: %s""" % foo)
     def psd(self):
         return self.n.psd()        
 
+    def force_time(self):
+
+        if state.force_time:
+            return self.time()
+        return self    
     
 from .cexpr import ConstantDomainExpression        
 from .fexpr import FourierDomainExpression    
