@@ -192,7 +192,7 @@ class LcapyTester(unittest.TestCase):
         a.add('H1 1 0 H1 -4')
         t = a.thevenin(1, 0)
         self.assertEqual(t.V, 0, "Incorrect Thevenin voltage")
-        self.assertEqual(t.Z, -4, "Incorrect Thevenin impedance")
+        self.assertEqual(t.Z, impedance(-4), "Incorrect Thevenin impedance")
         self.assertEqual(a.H1.Voc, 0, "Incorrect cpt voltage")
         self.assertEqual(a.H1.Z, 0, "Incorrect cpt impedance")         
 
@@ -203,7 +203,7 @@ class LcapyTester(unittest.TestCase):
         a = Circuit()
         a.add('V1 1 0 10') 
 
-        self.assertEqual(a.V1.V.dc, 10, "Incorrect voltage")
+        self.assertEqual(a.V1.V.dc, voltage(10), "Incorrect voltage")
 
 
     def test_VRL1_dc(self):
@@ -313,7 +313,7 @@ class LcapyTester(unittest.TestCase):
         a.add('W 0 3; right')
 
         self.assertEqual(a.sub['s'].is_causal, True, "Causal incorrect")
-        self.assertEqual2(a.L1.v, 2 * exp(-t) * u(t), "L current incorrect")
+        self.assertEqual2(a.L1.v, voltage(2 * exp(-t) * u(t)), "L current incorrect")
 
     def test_VR1_ac2(self):
         """Lcapy: check VR circuit at ac for angular frequency 1
@@ -508,7 +508,7 @@ class LcapyTester(unittest.TestCase):
 
         R 2 0 1""")
 
-        self.assertEqual(a.R.i, 10, "i incorrect")        
+        self.assertEqual(a.R.i, current(10), "i incorrect")        
 
     def test_K(self):
 
@@ -536,19 +536,19 @@ class LcapyTester(unittest.TestCase):
         V2 2 0 4
         R 1 0 2""")
 
-        self.assertEqual(a.R.V, 10, "incorrect series voltage")
+        self.assertEqual(a.R.V, voltage(10), "incorrect series voltage")
 
         b = a.kill('V1')
 
-        self.assertEqual(b.R.V, 4, "incorrect voltage with V1 killed")
+        self.assertEqual(b.R.V, voltage(4), "incorrect voltage with V1 killed")
 
         c = a.kill('V2')
 
-        self.assertEqual(c.R.V, 6, "incorrect voltage with V2 killed")
+        self.assertEqual(c.R.V, voltage(6), "incorrect voltage with V2 killed")
 
         d = a.kill_except('V1')
 
-        self.assertEqual(d.R.V, 6, "incorrect voltage with all killed except V1")
+        self.assertEqual(d.R.V, voltage(6), "incorrect voltage with all killed except V1")
         
         
     def test_TF(self):
@@ -659,6 +659,3 @@ class LcapyTester(unittest.TestCase):
 
         self.assertEqual(H1, H2, "transfer cpt/nodes")
         self.assertEqual(H1, -1, "transfer")        
-        
-        
-        
