@@ -19,8 +19,8 @@ class LcapyTester(unittest.TestCase):
     def test_tdomain_mul(self):
 
         v = voltage(5 * t)
-        self.assertEqual(v * 3, 15 * t, "v(t) * const")
-        self.assertEqual(3 * v, 15 * t, "const * v(t)")
+        self.assertEqual(v * 3, voltage(15 * t), "v(t) * const")
+        self.assertEqual(3 * v, voltage(15 * t), "const * v(t)")
 
     def test_sdomain_mul(self):
         
@@ -32,14 +32,16 @@ class LcapyTester(unittest.TestCase):
         U = sexpr(2)
         C = cexpr(3)
         
-        self.assertEqual(V * 3, 15 / s, "V(s) * const")
-        self.assertEqual(V * C, 15 / s, "V(s) * const")        
-        self.assertEqual(3 * V, 15 / s, "const * V(s)")
-        self.assertEqual(C * V, 15 / s, "const * V(s)")        
+        self.assertEqual(V * 3, voltage(15 / s), "V(s) * const")
+        self.assertEqual(V * C, voltage(15 / s), "V(s) * const")        
+        self.assertEqual(3 * V, voltage(15 / s), "const * V(s)")
+        self.assertEqual(C * V, voltage(15 / s), "const * V(s)")        
         self.assertEqual(Y * V, I, "Y(s) * V(s)")
         self.assertEqual(V * Y, I, "V(s) * Y(s)")
         self.assertEqual(I * Z, V, "I(s) * Z(s)")
-        self.assertEqual(Z * I, V, "Z(s) * I(s)")                
+        self.assertEqual(Z * I, V, "Z(s) * I(s)")
+        self.assertEqual(Z * Y, transfer(1), "Z(s) * Y(s)")
+        self.assertEqual(Y * Z, transfer(1), "Y(s) * Z(s)")
         self.assertEqual(V * H, voltage(50 / s), "V(s) * H(s)")
         self.assertEqual(H * V, voltage(50 / s), "H(s) * V(s)")
         self.assertEqual(I * H, current(sexpr(50)), "I(s) * H(s)")
@@ -56,10 +58,10 @@ class LcapyTester(unittest.TestCase):
         U = fexpr(2)
         C = cexpr(3)
         
-        self.assertEqual(V * 3, 15 / f, "V(f) * const")
-        self.assertEqual(V * C, 15 / f, "V(f) * const")
-        self.assertEqual(3 * V, 15 / f, "const * V(f)")
-        self.assertEqual(C * V, 15 / f, "const * V(f)")        
+        self.assertEqual(V * 3, voltage(15 / f), "V(f) * const")
+        self.assertEqual(V * C, voltage(15 / f), "V(f) * const")
+        self.assertEqual(3 * V, voltage(15 / f), "const * V(f)")
+        self.assertEqual(C * V, voltage(15 / f), "const * V(f)")        
         self.assertEqual(Y * V, I, "Y(f) * V(f)")
         self.assertEqual(V * Y, I, "V(f) * Y(f)")
         self.assertEqual(I * Z, V, "I(f) * Z(f)")
@@ -84,7 +86,7 @@ class LcapyTester(unittest.TestCase):
         H = transfer(sexpr(10))
         U = sexpr(2)        
         
-        self.assertEqual(V / 5, 1 / s, "V(s) / 5")
+        self.assertEqual(V / 5, voltage(1 / s), "V(s) / 5")
         self.assertEqual(V / Z, I, "V(s) / Z(s)")
         self.assertEqual(I / Y, V, "I(s) / Y(s)")
         self.assertEqual(I / H, current(sexpr(1 / 2)), "I(s) / H(s)")
@@ -114,14 +116,16 @@ class LcapyTester(unittest.TestCase):
         CZ = impedance(3)        
         
         self.assertEqual(V1 + V2, voltage(2 * s + 4), "V1(s) + V2(s)")
-        self.assertEqual(C + V1, voltage(3 + s), "C + V1(s)")
-        self.assertEqual(V1 + C, voltage(3 + s), "V1(s) + C")
-        self.assertEqual(V1 + 3, voltage(3 + s), "V1(s) + 3")
-        self.assertEqual(3 + V1, voltage(3 + s), "3 + V1(s)")
-        self.assertEqual(C + Z, impedance(3 * s + 3), "C + Z(s)")
-        self.assertEqual(Z + C, impedance(3 * s + 3), "Z(s) + C")
         self.assertEqual(CZ + Z, impedance(3 * s + 3), "CZ + Z(s)")
         self.assertEqual(Z + CZ, impedance(3 * s + 3), "Z(s) + CZ")        
+
+        loose = state.loose_units
+        state.loose_units = True
+        self.assertEqual(C + Z, impedance(3 * s + 3), "C + Z(s)")
+        self.assertEqual(Z + C, impedance(3 * s + 3), "Z(s) + C")
+        self.assertEqual(C + V1, voltage(3 + s), "C + V1(s)")
+        self.assertEqual(V1 + C, voltage(3 + s), "V1(s) + C")
+        state.loose_units = loose
         
     def test_fdomain_add(self):
         
@@ -130,10 +134,14 @@ class LcapyTester(unittest.TestCase):
         C = cexpr(3)
         
         self.assertEqual(V1 + V2, voltage(2 * f + 4), "V1(f) + V2(f)")
+
+        loose = state.loose_units        
+        state.loose_units = True        
         self.assertEqual(C + V1, voltage(3 + f), "C + V1(f)")
         self.assertEqual(V1 + C, voltage(3 + f), "V1(f) + C")
         self.assertEqual(V1 + 3, voltage(3 + f), "V1(f) + 3")
-        self.assertEqual(3 + V1, voltage(3 + f), "3 + V1(f)")                                        
+        self.assertEqual(3 + V1, voltage(3 + f), "3 + V1(f)")
+        state.loose_units = loose
         
     def test_rmul(self):
 
