@@ -21,15 +21,15 @@ class LcapyTester(unittest.TestCase):
         W 0_3 0_4; right""")
         ss = a.ss
 
-        self.assertEqual(ss.x[0], current('i_L(t)'), "x[0]")        
-        self.assertEqual(ss.x[1], voltage('v_C(t)'), "x[1]")
+        self.assertEqual(ss.x[0], expr('i_L(t)'), "x[0]")        
+        self.assertEqual(ss.x[1], expr('v_C(t)'), "x[1]")
 
         self.assertEqual(ss.x0[0], 0, "x0[0]")        
         self.assertEqual(ss.x0[1], 0, "x0[1]")
 
-        self.assertEqual(ss.y[0], voltage('v_1(t)'), "y[0]")        
+        self.assertEqual(ss.y[0], expr('v_1(t)'), "y[0]")        
 
-        self.assertEqual(ss.u[0], voltage('v(t)'), "u[0]")
+        self.assertEqual(ss.u[0], expr('v(t)'), "u[0]")
 
         self.assertEqual(ss.A[0, 0], expr('-R1/L'), "A[0, 0]")                
         
